#!/bin/bash
# This is a shell snippet containing some common functions to do menial tasks,
# Instead of duplicating effort in many places.

# Make sure we are user repeater!!!
if [ "`/usr/bin/whoami`" != "repeater" ] ; then
  echo "This program must be run as user REPEATER!"
  exit 1
fi

# Make sure we have sourced the environment file
if [ "${RUN_ENV}" != "TRUE" ] ; then
  echo "You must source the environment file first. Do this by running:"
  echo ". /home/irlp/custom/environment"
  exit 1
fi

#If the length of the stantionid is 6 (old three digit), it adds a zero
if [ "${#STATIONID}" = "6" ] ; then
  CONVERTED_STATIONID="${STATIONID}0"
else
  CONVERTED_STATIONID="${STATIONID}"
fi

# For GPL compliance, we will no longer distribute binaries for
# the following files:
#
# play / aplay
# record / arecord
# netcat (nc)
# wget
# rsync

# Instead, we will point to locally installed versions of these
# files, and remove the binary versions from new installs.
# $PLAY $RECORD $NETCAT and $WGET will represent these files.

# nc (netcat)
if [ -f /usr/bin/nc ] ; then
  NETCAT="/usr/bin/nc"
elif [ -f /bin/nc ] ; then
  NETCAT="/bin/nc"
elif [ -f /usr/sbin/nc ] ; then
  NETCAT="/usr/sbin/nc"
elif [ -f /sbin/nc ] ; then
  NETCAT="/sbin/nc"
else
  echo "`date '+%b %d %Y %T %z'` FAIL - nc (netcat) is not available" >> ${LOGFILE}
  NETCAT="${BIN}/nc"
fi

# rsync
if [ -f /usr/bin/rsync ] ; then
  RSYNC="/usr/bin/rsync"
elif [ -f /bin/rsync ] ; then
  RSYNC="/bin/rsync"
else
  echo "`date '+%b %d %Y %T %z'` FAIL - rsync is not available" >> ${LOGFILE}
  RSYNC="${BIN}/rsync"
fi

# wget
if [ -f /usr/bin/wget ] ; then
  WGET="/usr/bin/wget"
elif [ -f /bin/wget ] ; then
  WGET="/bin/wget"
else
  echo "`date '+%b %d %Y %T %z'` FAIL - wget is not available" >> ${LOGFILE}
  WGET="${BIN}/wget"
fi

# play
# If play is available, we use it first
if [ -f /usr/bin/play ] ; then
  PLAY="/usr/bin/play"
elif [ -f /bin/play ] ; then
  PLAY="/bin/play"
elif [ -f /usr/bin/aplay ] ; then
  PLAY="/usr/bin/aplay -q"
elif [ -f /bin/aplay ] ; then
  PLAY="/bin/aplay -q"
else
  echo "`date '+%b %d %Y %T %z'` FAIL - play is not available" >> ${LOGFILE}
  PLAY="${BIN}/play"
fi

# Added to get rid of the skipping audio on VIA chipsets on CentOS 4
if [ "${USE_APLAY}" = "YES" ] ; then
  if [ -f /usr/bin/aplay ] ; then
    PLAY="/usr/bin/aplay -q"
  elif [ -f /bin/aplay ] ; then
    PLAY="/bin/aplay -q"
  else
    PLAY="/usr/bin/play"
  fi
fi

# record
# if arecord is available, we use it first
if [ -f /usr/bin/arecord ] ; then
  RECORD="/usr/bin/arecord"
elif [ -f /bin/arecord ] ; then
  RECORD="/bin/arecord"
elif [ -f /usr/bin/record ] ; then
  RECORD="/usr/bin/record"
elif [ -f /usr/bin/rec ] ; then
  RECORD="/usr/bin/rec"
elif [ -f /bin/record ] ; then
  RECORD="/bin/record"
elif [ -f /bin/rec ] ; then
  RECORD="/bin/rec"
else
  echo "`date '+%b %d %Y %T %z'` FAIL - record or rec is not available" >> ${LOGFILE}
  RECORD=${BIN}/record
fi

# 2018-May-07 - Added code to create $IMIKE and $ISPEAKER tags, which properly
# add the AOSS and -8 flags depending on the settings in the environment file
#
# AOSS should be default on all new installs, so the check will soon be obsolete.
# Update - This is also applicable for CWPCM and DIAL programs - added


# IMIKE
# Note - Codecs are chosen in the scripts that call imike.
# The default is "aoss imike", but we need to have the options for:
# "imike"
# "imike -8"
# "aoss imike -8"

if [ "${USE_AOSS}" = "YES" ] ; then
  if [ "${FORCE_8BIT}" = "YES" ] ; then
    IMIKE="aoss ${BIN}/imike -8"
  else
    IMIKE="aoss ${BIN}/imike"
  fi
else
  if [ "${FORCE_8BIT}" = "YES" ] ; then
    IMIKE="${BIN}/imike -8"
  else
    IMIKE="${BIN}/imike"
  fi
fi

# ISPEAKER
# Note - Codecs are chosen in the scripts that call ispeaker.
# The default is "aoss ispeaker", but we need to have the options for:
# "ispeaker"
# "ispeaker -8"
# "aoss ispeaker -8"

if [ "${USE_AOSS}" = "YES" ] ; then
  if [ "${FORCE_8BIT}" = "YES" ] ; then
    ISPEAKER="aoss ${BIN}/ispeaker -8"
  else
    ISPEAKER="aoss ${BIN}/ispeaker"
  fi
else
  if [ "${FORCE_8BIT}" = "YES" ] ; then
    ISPEAKER="${BIN}/ispeaker -8"
  else
    ISPEAKER="${BIN}/ispeaker"
  fi
fi

# CWCPM - Morse code generator

if [ "${USE_AOSS}" = "YES" ] ; then
  CWPCM="aoss ${BIN}/cwpcm"
else
  CWPCM="${BIN}/cwpcm"
fi

# DIAL - DTMF generator

if [ "${USE_AOSS}" = "YES" ] ; then
  DIAL="aoss ${BIN}/dial"
else
  DIAL="${BIN}/dial"
fi


#########################################################################
### Functions

# This function creates four env vars with the four digits of a node, from
# a stationid name. ( of the form: "{stn,ref,}XXXX" )
# Syntax:  set_node_digits <node> <var1> <var2> <var3> <var4>
# Example: set_node_digits stn1234 N1 N2 N3 N4
#          echo $N1 $N2 $N3 $N4

function set_node_digits {
  NODE=$1 NUM1=$2 NUM2=$3 NUM3=$4 NUM4=$5

  if [ "${#NODE}" = "7" ]; then
    NODE="${NODE#???}"
  fi

  if [ "${#NODE}" != "4" \
    -o -z "$NUM1" -o -z "$NUM2" -o -z "$NUM3" -o -z "$NUM4" ] ; then
   echo "Bad arguments to set_node_digits()"
   exit 1
  fi

  eval TEMP1=${NODE#?} TEMP2=${NODE#??}
  eval NUM1=${NODE%???} NUM2=${TEMP1%??} NUM3=${TEMP2%?} NUM4=${NODE#???}
}

# Logging
function log {
  MESSAGE=$@
  if [ -n "${LOGFILE}" ]; then
    echo "`date '+%b %d %Y %T %z'` ${MESSAGE}" >> ${LOGFILE}
  fi
}

### End Functions
#########################################################################
